<?php
/*
Title: classe_atributos

Processa a tabela de atributos de um tema.

Lista valores, consulta, etc.

Licenca:

GPL2


I3Geo Interface Integrada de Ferramentas de Geoprocessamento para Internet

Direitos Autorais Reservados (c) 2006 Ministrio do Meio Ambiente Brasil
Desenvolvedor: Edmar Moretti edmar.moretti@mma.gov.br

Este programa  software livre; voc pode redistribu-lo
e/ou modific-lo sob os termos da Licena Pblica Geral
GNU conforme publicada pela Free Software Foundation;
tanto a verso 2 da Licena.
Este programa  distribudo na expectativa de que seja til,
porm, SEM NENHUMA GARANTIA; nem mesmo a garantia implcita
de COMERCIABILIDADE OU ADEQUAO A UMA FINALIDADE ESPECFICA.
Consulte a Licena Pblica Geral do GNU para mais detalhes.
Voc deve ter recebido uma cpia da Licena Pblica Geral do
GNU junto com este programa; se no, escreva para a
Free Software Foundation, Inc., no endereo
59 Temple Street, Suite 330, Boston, MA 02111-1307 USA.

Arquivo:

i3geo/classesphp/classe_atributos.php
*/
/*
Classe: Atributos

*/
class Atributos
{
	/*
	Variavel: $mapa
	
	Objeto mapa
	*/
	protected $mapa;
	/*
	Variavel: $arquivo
	
	Arquivo map file
	*/
	protected $arquivo;
	/*
	Variavel: $layer
	
	Objeto layer
	*/
	protected $layer;
	/*
	Variavel: $nome
	
	Nome do layer
	*/
	protected $nome;
/*
Function: __construct

Cria um objeto Atributos 

parameters:

$map_file - Endereo do mapfile no servidor.

$tema - nome do tema
*/
	function __construct($map_file,$tema="",$locaplic="")
	{
  		//error_reporting(E_ALL);
  		$this->locaplic = $locaplic;
  		$this->mapa = ms_newMapObj($map_file);
  		$this->arquivo = $map_file;
  		if($tema != "" && @$this->mapa->getlayerbyname($tema))
 		$this->layer = $this->mapa->getlayerbyname($tema);
  		$this->nome = $tema;
	}
/*
function: salva

Salva o mapfile atual
 
*/	
 	function salva()
 	{
	  	if (connection_aborted()){exit();}
	  	$this->mapa->save($this->arquivo);
	}

/*
function: extensaoShape

Pega a extenso geogrfica de um objeto shape.

parameters:
Objeto shape

return:
xmin ymin xmax ymax separados por espao.
*/
	function extensaoShape($shape)
	{
		if(!$this->layer){return "erro";}
		$prjMapa = $this->mapa->getProjection();
		$prjTema = $this->layer->getProjection();
		$ret = $shape->bounds;
		//reprojeta o retangulo
		if (($prjTema != "") && ($prjMapa != $prjTema))
		{
			$projInObj = ms_newprojectionobj($prjTema);
			$projOutObj = ms_newprojectionobj($prjMapa);
			$ret->project($projInObj, $projOutObj);
		}		
		$ext = $ret->minx." ".$ret->miny." ".$ret->maxx." ".$ret->maxy;
		if (($shape->type == MS_SHP_POINT) || ($shape->type == 0))
		{
			$minx = $ret->minx;
			$minx = $minx - 0.03;
			$maxx = $ret->maxx;
			$maxx = $maxx + 0.03;
			$miny = $ret->miny;
			$miny = $miny - 0.03;
			$maxy = $ret->maxy;
			$maxy = $maxy + 0.03;
			$ext = $minx." ".$miny." ".$maxx." ".$maxy;
		}
		return $ext;
	}
/*
function - extensaoRegistro

Pega a extenso geogrfica de um registro na tabela de atributos de um tema.

parameters:
$registro - ndice do registro que ser consultado.
*/
	function extensaoRegistro($registro)
	{
		if(!$this->layer){return "erro";}
		$this->layer->set("template","none.htm");
		$this->layer->setfilter("");
		$ext = "";
		//procura o registro e pega a extenso geogrfica
		if (@$this->layer->open() == MS_SUCCESS)
		{
			$items = pegaItens($this->layer);
			if (@$this->layer->queryByrect($this->mapa->extent) == MS_SUCCESS)
			{
				$this->layer->open();
				$shape = $this->layer->getfeature($registro,-1);
				$fechou = $this->layer->close();
				$ext = $this->extensaoShape($shape);
			}
		}
		return($ext);
	}
/*
function: listaItens

Lista os itens de um tema.
*/
	function listaItens()
	{
		//verifica se o tema  um grupo e cria um array com a lista de temas
		$vermultilayer = new vermultilayer();
		$vermultilayer->verifica($this->arquivo,$this->nome);
		if ($vermultilayer->resultado == 1) // o tema e multi layer
		{$l = $vermultilayer->temasvisiveis;}
		else
		{$l[] = $this->nome;}
		//pega os itens de cada layer
		$lista = array();
		foreach ($l as $tema)
		{
			$layer = $this->mapa->getlayerbyname($tema);
			//pega o nome correto do tema
			$nometmp = pegaNome($layer,"UTF-8");
			$nomestemas[] = $nometmp;
			if ($layer->data != "")
			{
					$items = pegaItens($layer);
					foreach ($items as $item)
					{
				 		$lista[] = array("item"=>$item,"nome"=>$nometmp,"tema"=>$tema);
					}
			}
		}
		return (array("valores"=>$lista,"temas"=>$l,"nomes"=>$nomestemas));
	}
/*
function: itensTexto

Pega todos os valores dos itens de uma tabela de um tema.

parameters:
$tipo - Tipo de busca brasil|null
*/
	function itensTexto($tipo)
	{
		if(!$this->layer){return "erro";}
		if ($tipo == "brasil")
		{$this->mapa = extPadrao($this->mapa);}
		$this->layer->set("template","none.htm");
		$this->layer->setfilter("");
		//le o arquivo de query se existir e checa se existe seleo para o tema
		$items = pegaItens($this->layer);
		$existesel = "nao";
		if (file_exists($this->arquivo."qy"))
		{$this->mapa->loadquery(($this->arquivo)."qy");}
		if ($this->layer->getNumresults() > 0){$existesel = "sim";}
		if ($existesel == "nao")
		{$this->layer->querybyrect($this->mapa->extent);}
		$sopen = $this->layer->open();
		if($sopen == MS_FAILURE){return "erro";}
		$registros[] = array();
		$res_count = $this->layer->getNumresults();
		for ($i = 0; $i < $res_count; ++$i)
		{
			$valitem = array();
			foreach ($items as $item)
			{
				$result = $this->layer->getResult($i);
				$shp_index  = $result->shapeindex;
				$shape = $this->layer->getfeature($shp_index,-1);
				$v = trim($shape->values[$item]);
				if (function_exists("mb_convert_encoding"))
				{$v = mb_convert_encoding($v,"UTF-8","ISO-8859-1");}
				$valitem[] = $v;
			}
			$registros[] = implode(";",$valitem);
		}
		$fechou = $this->layer->close();
		return(array("itens"=>implode(";",$items),"valores"=>$registros));
	}
/*
function: listaRegistros

Pega todos os valores dos itens de uma tabela de um tema.

O range de busca pode ser limitado.

parameters:
$itemtema - Tema que ser processado.

$tipo - Tipo de abrangncia espacial (brasil ou mapa).

$unico - Lista valores nicos (sim ou vazio).

$inicio - Inicia do registro.

$fim - Termina no registro.

$tipolista - Indica se sero mostrados todos os registros ou apenas os selecionados (tudo|selecionados)
*/
	function listaRegistros($itemtema,$tipo,$unico,$inicio,$fim,$tipolista)
	{
		if(!$this->layer){return "erro";}
		$resultadoFinal = array();
		if ((!isset($tipolista)) || ($tipolista=="")){$tipolista = "tudo";}
		if (!isset($inicio)){$inicio = 0;}
		if (!isset($fim)){$fim = "";}
		//se tipo for igual a brasil, define a extenso geogrfica total
		if ($tipo == "brasil")
		{$this->mapa = extPadrao($this->mapa);}
		$this->layer->set("template","none.htm");
		$this->layer->setfilter("");
		if ($this->layer->data == "")
		{return "erro. O tema no tem tabela";}
		//pega os valores
		if ((!isset($itemtema)) || ($itemtema == ""))
		{$items = pegaItens($this->layer);}
		else
		{$items[] = $itemtema;}
		$resultadoFinal[] = array("itens"=>$items);
		if (file_exists($this->arquivo."qy"))
		{$this->mapa->loadquery(($this->arquivo)."qy");}
		$indxlayer = $this->layer->index;
		$sopen = $this->layer->open();
		if($sopen == MS_FAILURE){return "erro";}
		$res_count = $this->layer->getNumresults();
		$registros = array();
		//lista apenas os selecionados
		if ($tipolista == "selecionados")
		{
			$chk = "CHECKED";
			if ($fim != "")
			{
				if (($res_count >= $fim) && ($fim < $res_count))
				{$res_count = $fim;}		
			}
			for ($i = $inicio; $i < $res_count; ++$i)
			{
				$valitem = array();
				foreach ($items as $item)
				{
					$result = $this->layer->getResult($i);
					$shp_index  = $result->shapeindex;
					$shape = $this->layer->getfeature($shp_index,-1);
					$valori = trim($shape->values[$item]);
					if (function_exists("mb_convert_encoding"))
					{$valori = mb_convert_encoding($valori,"UTF-8","ISO-8859-1");}
					$valitem[] = array("item"=>$item,"valor"=>$valori);
				}
				$registros[] = array("indice"=>$shp_index,"valores"=>$valitem,"status"=>$chk);
			}
			$resultadoFinal[] = array("registros"=>$registros);	 	
		}
		if ($tipolista == "tudo")
		{
			//ini_set('memory_limit', '500M');
			$shp_atual = array();
			for ($i = 0; $i < $res_count;++$i)
			{
				$rc = $this->layer->getResult($i);
				$shp_atual[$rc->shapeindex] = $rc->shapeindex;
			}
			$this->layer->close();
			$chk = "";
			if (@$this->layer->queryByrect($this->mapa->extent) == MS_SUCCESS)
			{
				$res_count = $this->layer->getNumresults();
				if ($fim != "")
				{
					if (($res_count >= $fim) && ($fim < $res_count))
					{$res_count = $fim;}		
				}
				$sopen = $this->layer->open();
				if($sopen == MS_FAILURE){return "erro";}
				for ($i = $inicio; $i < $res_count; ++$i)
				{
					$valitem = array();
					foreach ($items as $item)
					{
						$result = $this->layer->getResult($i);
						$shp_index  = $result->shapeindex;
						$shape = $this->layer->getfeature($shp_index,-1);
						$valori = "";
						if(@$shape->values[$item])
						{
							$valori = ($shape->values[$item]);
						}
						$valori = $valori = mb_convert_encoding($valori,"UTF-8","ISO-8859-1");
						$valitem[] = array("item"=>$item,"valor"=>$valori);
					}
					//if (in_array($shp_index,$shp_atual))
					if(isset($shp_atual[$shp_index]))
					{$chk = "CHECKED";}
					$registros[] = array("indice"=>$shp_index,"valores"=>$valitem,"status"=>$chk);
					$chk = "";
				}
				$this->layer->close();
			}
			$resultadoFinal[] = array("registros"=>$registros);
		}
		return($resultadoFinal);
	}
/*
function: buscaRegistros

Procura valores em uma tabela que aderem a uma palavra de busca.

parameters:
$palavra - Palavra que ser procurada.

$lista - Lista de busca no formato item;tema,item;tema.

$tipo - Tipo de busca exata|qualquer.

$onde - Tipo de abrangncia espacial (brasil ou mapa)
*/
	function buscaRegistros($palavra,$lista,$tipo,$onde)
	{
		if ($onde == "mapa")
		{$this->mapa = extPadrao($this->mapa);}
		$ptvs = explode(",",$lista);
		//monta a lista de temas que serao utilizados
		foreach ($ptvs as $p)
		{
			$pp = explode(";",$p);
			$temas[] = $pp[1];
		}
		$temas = array_unique($temas);
		//monta a lista de itens por tema
		foreach ($temas as $tema)
		{
			$temp = array();
			foreach ($ptvs as $p)
			{
				$pp = explode(";",$p);
				if ($pp[1] == $tema)
				{$temp[] = $pp[0];}
				$temasi[$tema] = $temp;
			}
		}
		$encontrado = "nao";
		$palavra = trim($palavra);
		foreach ($temas as $tema)
		{
			$registros = array();
			$items = $temasi[$tema];
			$l = $this->mapa->getlayerbyname($tema);
			$this->layer = $l;
			if ($l->data == "")
			{return "Erro. O tema no tem tabela";}
			$filtro = $l->getfilterstring();
			if ($filtro != ""){$l->setfilter("");}
			$buscas = "";
			$buscasUTF = mb_convert_encoding($buscas,"UTF-8","ISO-8859-1");
			$trocas = "AAOOOaaaaoooouuieecAAOOOaaaaoooouuieec";
			$buscas = $buscas.$buscasUTF;
			$sopen = $l->open();
			if($sopen == MS_FAILURE){return "erro";}
			$l->whichShapes($this->mapa->extent);
			$fr = array();
			while ($shape = $l->nextShape())
			{
				$novoreg = array();
				$r = array();
				foreach ($items as $item)
				{
					$v = trim($shape->values[$item]);
					if ($tipo == "exata")
					{
						if (strtr($v,$buscas,$trocas) == strtr($palavra,$buscas,$trocas))
						{
							if (function_exists("mb_convert_encoding"))
							{$v = mb_convert_encoding($v,"UTF-8","ISO-8859-1");}	
							$r[] = array("item" => $item,"valor" => $v);
							$encontrado = "sim";
  						}
					}
					else
					{
						if (stristr(strtr($v,$buscas,$trocas),strtr($palavra,$buscas,$trocas)))
						{
							if (function_exists("mb_convert_encoding"))
							{$v = mb_convert_encoding($v,"UTF-8","ISO-8859-1");}
							$r[] = array("item" => $item,"valor" => $v);
							$encontrado = "sim";
						}
					}
				}
				if ($encontrado == "sim")
				{
					$novoreg["box"] = $this->extensaoShape($shape,$l);			
					$novoreg["valores"] = $r;
					$encontrado = "nao";
					$fr[] = $novoreg;
				}
			}
			$resultado[] = array("tema"=>$tema,"resultado"=>$fr);
			$l->close();
		}
		return($resultado);
	}
/*
function: estatDescritivas

Calcula estatsticas bsicas de uma tabela de um tema.

parameters:
$item - Item que ser calculado.

$exclui - Valor que no ser cosiderado.

Include:
<classe_estatistica.php>
*/
	function estatDescritivas($item,$exclui)
	{
		if(!$this->layer){return "erro";}
		$this->layer->set("template","none.htm");
		$items = pegaItens($this->layer);
		$valores = array();
		$filtro = $this->layer->getfilterstring();
		if ($filtro != ""){$this->layer->setfilter("");}
		//le o arquivo de query se existir e checa se existe sele&ccedil;&atilde;o para o tema
		$existesel = "nao";
		if (file_exists(($this->arquivo)."qy"))
		{$this->mapa->loadquery(($this->arquivo)."qy");}
		if ($this->layer->getNumresults() > 0){$existesel = "sim";}
		if ($existesel == "nao")
		{$this->layer->queryByrect($this->mapa->extent);}
		$sopen = $this->layer->open();
		if($sopen == MS_FAILURE){return "erro";}
		$res_count = $this->layer->getNumresults();
		//pega os valores
		for ($i = 0; $i < $res_count; ++$i)
		{
			$result = $this->layer->getResult($i);
			$shp_index  = $result->shapeindex;
			$shape = $this->layer->getfeature($shp_index,-1);
			$v = $shape->values[$item];
			$valores[] = $v;
		}
		$fechou = $this->layer->close();
		$valoresn = array();
		//verifica se a lista de valores contem numeros e exclusao
		foreach ($valores as $valor)
		{
			if (is_numeric($valor))
			{
				if ($exclui != "")
				{
					if ($valor != $exclui)
					{$valoresn[] = $valor;}
				}
				else
				{$valoresn[] = $valor;}
			}
		}
		if (count($valoresn) == 0)
		{return("erro. Nenhum valor valido");}
		//faz os calculos
		if(file_exists($this->locaplic."/classe_estatistica.php"))
		include_once($this->locaplic."/classe_estatistica.php");
		else	
		include_once("classe_estatistica.php");
		$estat = new estatistica();
		$resultado = $estat->calcula($valoresn);
		$resultado = $estat->resultado;
		$indice = $estat->indice;
		if ($resultado['min'] == "")
		{return("erro. Nenhum valor valido");}
		$chaves = array_keys($indice);
		return(array("indices"=>$chaves,"variaveis"=>$indice,"valores"=>$resultado));
	}
/*
function: identifica

Depreciado na verso 4.2 (utilize "identifica2")

Identifica elementos no mapa.

parameters:
$opcao - Opcao tip|tema|ligados|todos.

$xy - coordenada x e y separadas por virgulao.

$resolucao - Resolucao de busca.
*/
	function identifica($opcao,$xy,$resolucao)
	{
		$temas = $this->mapa->getalllayernames();
		foreach ($temas as $tem)
		{
			$vermultilayer = new vermultilayer();
			$vermultilayer->verifica($this->arquivo,$tem);
			if ($vermultilayer->resultado == 1) // o tema e multi layer
			{
				foreach (($vermultilayer->temasvisiveis) as $tv)
				{
					$l = $this->mapa->getlayerbyname($tv);
					if ($l->getmetadata("identifica") != "nao")
					{$listatemas[] = $tv;}
				}
			}
			else
			{
		 		$l = $this->mapa->getlayerbyname($tem);
				if (($l->getmetadata("escondido") == "") && ($l->getmetadata("identifica") != "nao"))
				{$listatemas[] = $tem;}
			}
		}
		$listatemas = array_unique($listatemas);
		$xyarray = explode(",",$xy);
		$resultados = array();
		//pesquisa um tema
		if ($opcao == "tema")
		{
			$listatemas = array();
			$vermultilayer = new vermultilayer();
			$vermultilayer->verifica($this->arquivo,$this->nome);
			if ($vermultilayer->resultado == 1) // o tema e multi layer
			{$listatemp = $vermultilayer->temasvisiveis;}
			else
			{$listatemp[] = $this->nome;}
			foreach ($listatemp as $t)
			{
				$layerteste = $this->mapa->getlayerbyname($t);
				$mclasse = strtoupper($layerteste->getmetadata("CLASSE"));
				$mtema = strtoupper($layerteste->getmetadata("TEMA"));
				$gr = $layerteste->group;
				if ((!(($mclasse == "NAO") && ($mtema == "NAO"))) || ($gr != ""))
				{
					if (($layerteste->data != "") && ($layerteste->connectiontype != MS_WMS))
					{$listatemas[] = $t;}
				}
			}
			$layerteste = $this->layer;
			if ($layerteste->connectiontype == MS_WMS)
			{
				$listatemas = array();
				$listatemas[] = $this->nome;
			}
			foreach ($listatemas as $tema)
			{
				$resultados[$tema] = $this->identificaQBP($tema,$xyarray[0],$xyarray[1],$this->arquivo,$resolucao);
			}
		}
		//pesquisa todos os temas acrescentados no mapa
		if ($opcao == "todos")
		{
			foreach ($listatemas as $tema)
			{
				$resultados[$tema] = $this->identificaQBP($tema,$xyarray[0],$xyarray[1],$this->arquivo,$resolucao);
			}
		}
		//pesquisa apenas os temas visiveis
		if ($opcao == "ligados")
		{
			$novalista = array();
			foreach ($listatemas as $tema)
			{
				$l = $this->mapa->getlayerbyname($tema);
				if($l->status == MS_DEFAULT)
				$novalista[] = $tema;
				$listatemas = $novalista;
			}
			foreach ($listatemas as $tema)
			{
				$l = $this->mapa->getlayerbyname($tema);
				$resultados[$tema] = $this->identificaQBP($tema,$xyarray[0],$xyarray[1],$this->arquivo,$resolucao);
			}
			//var_dump($resultados);
		}
		//pesquisa apenas os temas com tip
		if ($opcao == "tip")
		{
			$ltemp = array();
			foreach ($listatemas as $tema)
			{
				$tl = $this->mapa->getlayerbyname($tema);
				$itemtip = $tl->getmetadata("TIP");
				if ($itemtip != "")
				{
					if ($tl->status == MS_DEFAULT)
					{
						$resultados[$tema] = $this->identificaQBP($tema,$xyarray[0],$xyarray[1],$this->arquivo,$resolucao,$itemtip);
						$ltemp[] = $tema;
					}
				}
			}
			$listatemas = $ltemp;
		}
		if (count($resultados) > 0)
		{
			if (function_exists("mb_convert_encoding"))
			{$res = mb_convert_encoding($this->retornaI($listatemas,$resultados,$this->mapa),"UTF-8","ISO-8859-1");}
			else
			{$res = $this->retornaI($listatemas,$resultados,$this->mapa);}
			return($res);
		}
		else
		{return("");}
	}
/*
function: identifica2

Identifica elementos no mapa.

parameters:

$opcao - Opcao tip|tema|ligados|todos.

$xy - coordenada x e y separadas por virgulao.

$resolucao - Resolucao de busca.
*/
	function identifica2($opcao,$xy,$resolucao)
	{
		$temas = $this->mapa->getalllayernames();
		foreach ($temas as $tem)
		{
			$vermultilayer = new vermultilayer();
			$vermultilayer->verifica($this->arquivo,$tem);
			if ($vermultilayer->resultado == 1) // o tema e multi layer
			{
				foreach (($vermultilayer->temasvisiveis) as $tv)
				{
					$l = $this->mapa->getlayerbyname($tv);
					if ($l->getmetadata("identifica") != "nao")
					{$listatemas[] = $tv;}
				}
			}
			else
			{
		 		$l = $this->mapa->getlayerbyname($tem);
				if (($l->getmetadata("escondido") == "") && ($l->getmetadata("identifica") != "nao"))
				{$listatemas[] = $tem;}
			}
		}
		$listatemas = array_unique($listatemas);
		$xyarray = explode(",",$xy);
		$resultados = array();
		//pesquisa um tema
		if ($opcao == "tema")
		{
			$listatemas = array();
			$vermultilayer = new vermultilayer();
			$vermultilayer->verifica($this->arquivo,$this->nome);
			if ($vermultilayer->resultado == 1) // o tema e multi layer
			{$listatemp = $vermultilayer->temasvisiveis;}
			else
			{$listatemp[] = $this->nome;}
			foreach ($listatemp as $t)
			{
				$layerteste = $this->mapa->getlayerbyname($t);
				$mclasse = strtoupper($layerteste->getmetadata("CLASSE"));
				$mtema = strtoupper($layerteste->getmetadata("TEMA"));
				$gr = $layerteste->group;
				if ((!(($mclasse == "NAO") && ($mtema == "NAO"))) || ($gr != ""))
				{
					if (($layerteste->data != "") && ($layerteste->connectiontype != MS_WMS) || ($layerteste->tileindex != ""))
					{$listatemas[] = $t;}
				}
			}
			$layerteste = $this->layer;
			if ($layerteste->connectiontype == MS_WMS)
			{
				$listatemas = array();
				$listatemas[] = $this->nome;
			}
			foreach ($listatemas as $tema)
			{
				$resultados[$tema] = $this->identificaQBP2($tema,$xyarray[0],$xyarray[1],$this->arquivo,$resolucao);
			}
		}
		//pesquisa todos os temas acrescentados no mapa
		if ($opcao == "todos")
		{
			foreach ($listatemas as $tema)
			{
				$resultados[$tema] = $this->identificaQBP2($tema,$xyarray[0],$xyarray[1],$this->arquivo,$resolucao);
			}
		}
		//pesquisa apenas os temas visiveis
		if ($opcao == "ligados")
		{
			$novalista = array();
			foreach ($listatemas as $tema)
			{
				$l = $this->mapa->getlayerbyname($tema);
				if($l->status == MS_DEFAULT)
				$novalista[] = $tema;
				$listatemas = $novalista;
			}
			foreach ($listatemas as $tema)
			{
				$l = $this->mapa->getlayerbyname($tema);
				$resultados[$tema] = $this->identificaQBP2($tema,$xyarray[0],$xyarray[1],$this->arquivo,$resolucao);
			}
			//var_dump($resultados);
		}
		//pesquisa apenas os temas com tip
		if ($opcao == "tip")
		{
			$ltemp = array();
			foreach ($listatemas as $tema)
			{
				$tl = $this->mapa->getlayerbyname($tema);
				$itemtip = $tl->getmetadata("TIP");
				if ($itemtip != "")
				{
					if ($tl->status == MS_DEFAULT)
					{
						$resultados[$tema] = array("tips"=>$itemtip,"dados"=>$this->identificaQBP2($tema,$xyarray[0],$xyarray[1],$this->arquivo,$resolucao,$itemtip,"",true));
						$ltemp[] = $tema;
					}
				}
			}
			$listatemas = $ltemp;
		}
		if (count($resultados) > 0)
		{
			$res = $this->retornaI2($listatemas,$resultados,$this->mapa);
			return($res);
		}
		else
		{return("");}
	}
/*
function: retornaI2

Depreciado na verso 4.2

Processa o resultado da identificao de um elemento compondo um array de strings formatadas.

parameters:
$listatemas - Lista de temas

$resultados - Resultados de cada tema.

$map - Objeto Map.
*/
function retornaI2($listatemas,$resultados,$map)
{
	$final = array();
	foreach ($listatemas as $tema)
	{
		$layer = $map->getlayerbyname($tema);
		$nometmp = $tema;
		if (strtoupper($layer->getMetaData("TEMA")) != "NAO")
		{$nometmp = $layer->getMetaData("TEMA");}
		else if ($layer->getMetaData("ALTTEMA") != "")
		{$nometmp = $layer->getMetaData("ALTTEMA");}
		$nometmp = mb_convert_encoding($nometmp,"UTF-8","ISO-8859-1");
		$final[] = array("nome"=>$nometmp,"resultado"=>$resultados[$tema]);
	}
	return $final;
}

/*
function: retornaI

Depreciado na verso 4.2

Processa o resultado da identificao de um elemento compondo um array de strings formatadas.

parameters:
$listatemas - Lista de temas

$resultados - Resultados de cada tema.

$map - Objeto Map.
*/
function retornaI($listatemas,$resultados,$map)
{
	$final = "";
	foreach ($listatemas as $tema)
	{
		$layer = $map->getlayerbyname($tema);
		//pega o nome correto do tema
		$nometmp = $tema;
		if (strtoupper($layer->getMetaData("TEMA")) != "NAO")
		{$nometmp = $layer->getMetaData("TEMA");}
		else if ($layer->getMetaData("ALTTEMA") != "")
		{$nometmp = $layer->getMetaData("ALTTEMA");}
		$final = $final."!".$nometmp;
		$final = trim($final,"!");
		$rs = $resultados[$tema];
		$final = $final."@";
		foreach ($rs as $r)
		{
			$final = $final . "*";
			if ($r != " ")
			{
				foreach ($r as $f)
				{$final = $final . $f;}
			}
		}
	}
	return $final;
}
/*
function: identificaQBP

Depreciado na verso 4.2

Identifica um elemento utilizando querybypoint.

parameters:

$tema - Tema que ser identificado

$x - Coordenada X.

$y - Coordenada Y.

$map_file - Arquivo map file.

$resolucao - Resoluo de busca.

$item - Item nico que ser identificado.

$tiporetorno - Tipo de retorno dos dados. Se for vazio, o retorno  formatado como string, se for shape, retorna o objeto shape 
*/
function identificaQBP($tema,$x,$y,$map_file,$resolucao,$item="",$tiporetorno="")
{
	$mapa = ms_newMapObj($map_file);
	$layer = $mapa->getLayerByName($tema);
	$layer->set("status",MS_DEFAULT);
	$layer->set("template","none.htm");
	$pt = ms_newPointObj();
	$pt->setXY($x,$y);
	//
	//operao especial para o caso de wms
	//
	if($layer->connectiontype == MS_WMS)
	{
		$layer->set("toleranceunits",MS_PIXELS);
		$layer->set("tolerance",$resolucao);
		$ptimg = xy2imagem($map_file,array($x,$y));
		$mapa = desligatemas($mapa);
		$mapa = desligamargem($mapa);
		$imgo = $mapa->draw();
		//$res = $layer->getWMSFeatureInfoURL($ptimg->x, $ptimg->y, 1,"MIME");
		$resultado = array();
		$res = $layer->connection;
		$res .= "&request=getfeatureinfo&service=wms";
		$res .= "&version=1.1.0";//.($layer->getmetadata("wms_version"));
		$res .= "&QUERY_LAYERS=".($layer->getmetadata("wms_name"));
		$res .= "&LAYERS=".($layer->getmetadata("wms_name"));
		$bb = $mapa->extent;
		$res .= "&BBOX=".($bb->minx).",".($bb->miny).",".($bb->maxx).",".($bb->maxy);
		$res .= "&X=".round($ptimg->x);
		$res .= "&Y=".round($ptimg->y);
		$res .= "&WIDTH=".$mapa->width;
		$res .= "&HEIGHT=".$mapa->height;
		$formatoinfo = "text/plain";
		$formatosinfo = $layer->getmetadata("formatosinfo");
		if ($formatosinfo != "")
		{
			$formatosinfo = explode(",",$formatosinfo);
			if ($formatosinfo[0] != ""){$formatoinfo = $formatosinfo[0];}
			foreach ($formatosinfo as $f)
			{
		 		if(strtoupper($f) == "TEXT/PLAIN")
		 		{$formatoinfo = "text/plain";}
			}
					
		}
		$srs = $layer->getmetadata("wms_srs");
		$srss = explode(" ",$srs);
		$srs = "EPSG:4326";
		foreach ($srss as $s)
		{
		 	if(strtoupper($s) == "EPSG:4291")
		 	{$srs = "EPSG:4291";}
		}
		$res .= "&SRS=".$srs;
		$resposta = file($res."&FORMAT=".$formatoinfo);
		$resposta = str_ireplace('<?xml version="1.0" encoding="UTF-8"?>',"",$resposta);
		$resposta = str_ireplace('<?xml version="1.0" encoding="ISO-8859-1"?>',"",$resposta);
		$resposta = str_ireplace("<?xml version='1.0' encoding='ISO-8859-1'?>","",$resposta);
		$resposta = str_ireplace('<?xml',"",$resposta);
		$resposta = str_ireplace("<","zzzzzzzzzz",$resposta);
		$resposta = str_ireplace(">","zzzzzzzzzz",$resposta);
		if (stristr(implode(" ",$resposta),"msWMSLoadGetMapParams"))
		{
			$resposta = file($res);
			$resposta = str_ireplace('<?xml version="1.0" encoding="UTF-8"?>',"",$resposta);
			$resposta = str_ireplace('<?xml version="1.0" encoding="ISO-8859-1"?>',"",$resposta);
			$resposta = str_ireplace("<?xml version='1.0' encoding='ISO-8859-1'?>","",$resposta);
			$resposta = str_ireplace('<?xml',"",$resposta);
			$resposta = str_ireplace("<","zzzzzzzzzz",$resposta);
			$resposta = str_ireplace(">","zzzzzzzzzz",$resposta);
		}
		$resultado[] = $resposta;
		return $resultado;		
	}
	if(($layer->connectiontype != MS_WMS) && ($layer->type == MS_LAYER_RASTER))
	{
		$layer->set("toleranceunits",MS_PIXELS);
		$layer->set("tolerance",$resolucao);
		$ident = @$layer->queryByPoint($pt, 0, 0); //0.01);
	}
	if (($layer->type == MS_LAYER_POINT) || ($layer->type == MS_LAYER_LINE))
	{
		$layer->set("toleranceunits",MS_PIXELS);
		$layer->set("tolerance",$resolucao);
		$ident = @$layer->queryByPoint($pt, 1, 0); //0.01);
	}
	if ($layer->type == MS_LAYER_POLYGON)
	{
		$layer->set("toleranceunits",'MS_PIXEL');
		$layer->set("tolerance",1);
		$ident = @$layer->queryByPoint($pt, 1, 0);
	}
	if ($ident == MS_SUCCESS)
	{
		$its = $layer->getmetadata("ITENS"); // itens
		if ($item != "") //utilizado pela funcao tip
		{$its = $item;}
		if ($its != "")
		{
			$descis = $layer->getmetadata("ITENSDESC"); // descri&ccedil;&atilde;o dos itens
			$descisarray = explode(",",$descis); // array com a descri&ccedil;&atilde;o dos itens
			$itsarray = explode(",",$its); // array com os nomes dos itens
			$lks = $layer->getmetadata("ITENSLINK"); // link dos itens
			$itemimg = $layer->getmetadata("ITEMIMG"); //indica um item que ser utilizado para colocar um cone
			$locimg = $layer->getmetadata("IMGLOC"); //indica o local onde esto os cones
			$lksarray = explode(",",$lks);
			if ($item != "") //utilizado pela funcao tip
			{
				$descis = $item;
				$descisarray = array();
				$descisarray[] = $item;
				$lksarray = array();
			}
		}
		else
		{
			if ($item != "") //utilizado pela funcao tip
			{
				$descisarray[] = $item;
				$lksarray = array();
			}
			else
			{
				$descisarray = pegaItens($layer);
				$itsarray = pegaItens($layer);
				$lksarray = array();
			}
		}
		$res_count = $layer->getNumresults();
		$sopen = $layer->open();
		if($sopen == MS_FAILURE){return "erro";}
		for ($i = 0; $i < $res_count; ++$i)
		{
			$valori = array();
			$result = $layer->getResult($i);
			$shp_index  = $result->shapeindex;
			$shape = $layer->getfeature($shp_index,-1);
			if ($tiporetorno == "shape")
			{
				$layer->close();
				return $shape;
			}
			if ($tiporetorno == "unico")
			{
				$layer->close();
				return $shape->values[$itsarray[0]];;
			}
			$conta = 0;
			foreach ($itsarray as $it)
			{
				$val = $shape->values[$it];
				if ($val == ""){$val = "-";}
				if(!@$lksarray[$conta]){$lksarray[$conta] = "";}
				if ($lksarray[$conta] == "") //descricao,valor,link
				{
					if(!@$descisarray[$conta]){$descisarray[$conta] = "";}
					$valori[] = $descisarray[$conta].":#".($val)."#"." ";
				}
				else
				{
					$nli = $descisarray[$conta].":#".$val."#".$lksarray[$conta];
					$itemstab = pegaItens($layer);
					foreach ($itemstab as $itab)
					{
						$busca = '['.$itab.']';
						$nli = str_replace($busca,$shape->values[$itab],$nli);
					}
					$valori[] = $nli;
				}
				if ((@$shape->values[$itemimg]) && ($itemimg != "")) //incluir icone
				{
					$valori[] = "<img src=..//".$locimg."//".$shape->values[$itemimg].".png //># # ";
				}
				$conta = $conta + 1;
			}
			$valori = implode("@##",$valori);
			$valori = explode("@",$valori);
			$resultado[] = $valori;
		}
		$layer->close();
	}
	else
	{$resultado[] = " ";}
	return $resultado;
}
	/*
	function: identificaQBP2

	Identifica um elemento utilizando querybypoint.

	parameters:

	$tema - Tema que ser identificado

	$x - Coordenada X.

	$y - Coordenada Y.

	$map_file - Arquivo map file.

	$resolucao - Resoluo de busca.

	$item - Item nico que ser identificado.

	$tiporetorno - Tipo de retorno dos dados. Se for vazio, o retorno  formatado como string, se for shape, retorna o objeto shape 

	$etip  booblean - indica se a solicitao  para obteno dos dados do tipo etiqueta
	*/
	function identificaQBP2($tema,$x,$y,$map_file,$resolucao,$item="",$tiporetorno="",$etip=false)
	{
		$mapa = ms_newMapObj($map_file);
		if($ext != ""){
			$extmapa = $mapa->extent;
			$e = explode(" ",$ext);
			$extmapa->setextent((min($e[0],$e[2])),(min($e[1],$e[3])),(max($e[0],$e[2])),(max($e[1],$e[3])));
		}
		$layer = $mapa->getLayerByName($tema);
		$layer->set("status",MS_DEFAULT);
		$layer->set("template","none.htm");
		$pt = ms_newPointObj();
		$pt->setXY($x, $y);
		//
		//operao especial para o caso de wms
		//
		if($layer->connectiontype == MS_WMS)
		{
			$layer->set("toleranceunits",MS_PIXELS);
			$layer->set("tolerance",$resolucao);
			$ptimg = xy2imagem($map_file,array($x,$y));
			$mapa = desligatemas($mapa);
			$mapa = desligamargem($mapa);
			$imgo = $mapa->draw();

			$formatoinfo = "MIME";
			$formatosinfo = $layer->getmetadata("formatosinfo");
			if ($formatosinfo != "")
			{
				$formatosinfo = explode(",",$formatosinfo);
				if ($formatosinfo[0] != ""){$formatoinfo = $formatosinfo[0];}
				foreach ($formatosinfo as $f)
				{
					if(strtoupper($f) == "TEXT/PLAIN")
					{$formatoinfo = "text/plain";}
				}						
			}
			/*
			$srs = $layer->getmetadata("wms_srs");
			$srss = explode(" ",$srs);
			$srs = "EPSG:4326";
			foreach ($srss as $s)
			{
				if(strtoupper($s) == "EPSG:4291")
				{$srs = "EPSG:4291";}
			}
			$res .= "&SRS=".$srs;
			$resposta = file($res."&FORMAT=".$formatoinfo);
			*/
			$res = $layer->getWMSFeatureInfoURL($ptimg->x, $ptimg->y, 1,$formatoinfo);
			$res = str_replace("INFOFORMAT","INFO_FORMAT",$res);
			$res2 = $layer->getWMSFeatureInfoURL($ptimg->x, $ptimg->y, 1,"MIME");
			$res2 = str_replace("INFOFORMAT","INFO_FORMAT",$res2);
			$resposta = file($res);
	/*		
			$resposta = str_ireplace('<?xml version="1.0" encoding="UTF-8"?>',"",$resposta);
			$resposta = str_ireplace('<?xml version="1.0" encoding="ISO-8859-1"?>',"",$resposta);
			$resposta = str_ireplace("<?xml version='1.0' encoding='ISO-8859-1'?>","",$resposta);
			$resposta = str_ireplace('<?xml',"",$resposta);
			$resposta = str_ireplace("<","zzzzzzzzzz",$resposta);
			$resposta = str_ireplace(">","zzzzzzzzzz",$resposta);
			if (stristr(implode(" ",$resposta),"msWMSLoadGetMapParams"))
			{
				$resposta = file($res);
				$resposta = str_ireplace('<?xml version="1.0" encoding="UTF-8"?>',"",$resposta);
				$resposta = str_ireplace('<?xml version="1.0" encoding="ISO-8859-1"?>',"",$resposta);
				$resposta = str_ireplace("<?xml version='1.0' encoding='ISO-8859-1'?>","",$resposta);
				$resposta = str_ireplace('<?xml',"",$resposta);
				$resposta = str_ireplace("<","zzzzzzzzzz",$resposta);
				$resposta = str_ireplace(">","zzzzzzzzzz",$resposta);
			}
	*/
			$n = array();
			foreach($resposta as $r)
			{
				$t = explode("=",$r);
				$v = str_replace("\\n","",$t[1]);
				$v = str_replace("\\r","",$v);
				if(trim($v) != "")
				{
					$va = trim($v);
					$va = $this->converte($va);
					$n[] = array("alias"=>trim($t[0]),"valor"=>$va,"link"=>"","img"=>"");
				}
			}
			//caso esri
			if($n[0] == "")
			{
				//error_reporting(E_ALL);
				$resposta = file($res);
				$cabecalho = str_replace('"   "','"|"',$resposta[0]);
				$cabecalho = explode("|",$cabecalho);
				
				$linha = str_replace('"  "','"|"',$resposta[1]);
				$linha = explode("|",$linha);
				for($i=0;$i < count($cabecalho);++$i)
				{
					$va = $this->converte($linha[$i]);
					$n[] = array("alias"=>$cabecalho[$i],"valor"=>$va,"link"=>"","img"=>"");
				}
			}
			
			$n[] = array("alias"=>"Link WMS","valor"=>"getfeatureinfo ".$formatoinfo,"link"=>$res,"img"=>"");
			$n[] = array("alias"=>"Link WMS","valor"=>"getfeatureinfo padr&atilde;o do servi&ccedil;o","link"=>$res2,"img"=>"");
			return array($n);		
		}
		if(($layer->connectiontype != MS_WMS) && ($layer->type == MS_LAYER_RASTER))
		{
			$layer->set("toleranceunits",MS_PIXELS);
			$layer->set("tolerance",$resolucao);
			$ident = @$layer->queryByPoint($pt, 0, 0); //0.01);
		}
		//error_reporting(E_ALL);
		if (($layer->type == MS_LAYER_POINT) || ($layer->type == MS_LAYER_LINE) || ($layer->type == MS_LAYER_CHART))
		{
			$layer->set("toleranceunits",MS_PIXELS);
			$layer->set("tolerance",$resolucao);
			$ident = @$layer->queryByPoint($pt, 1, -1); //0.01);
		}
		if ($layer->type == MS_LAYER_POLYGON)
		{
			$layer->set("toleranceunits",MS_PIXELS);
			$layer->set("tolerance",$resolucao);
			$ident = @$layer->queryByPoint($pt, 1, -1);
		}

		if ($ident == MS_SUCCESS)
		{
			$itens = $layer->getmetadata("ITENS"); // itens
			$itensdesc = $layer->getmetadata("ITENSDESC"); // descri&ccedil;&atilde;o dos itens
			$lks = $layer->getmetadata("ITENSLINK"); // link dos itens
			$itemimg = $layer->getmetadata("ITEMIMG"); //indica um item que ser utilizado para colocar um cone
			$locimg = $layer->getmetadata("IMGLOC"); //indica o local onde esto os cones
			$tips = $layer->getmetadata("TIP");
			$itensLayer = pegaItens($layer);
			
			$nitens = count($itensLayer);

			if($itens == "")
			{$itens = $itensLayer;}
			else
			{$itens = explode(",",$itens);}
			
			if($itensdesc == "")
			{$itensdesc = $itensLayer;}//array_fill(0, $nitens-1,'');}
			else
			{$itensdesc = explode(",",$itensdesc);}
			
			if($lks == "")
			{$lks = array_fill(0, $nitens-1,'');}
			else
			{$lks = explode(",",$lks);}
					
			if($itemimg == "")
			{$itemimg = array_fill(0, $nitens-1,'');}
			else
			{$itemimg = explode(",",$itemimg);}	
				
			if($locimg == "")
			{$locimg = array_fill(0, $nitens-1,'');}
			else
			{$locimg = explode(",",$locimg);}
			//o retorno deve ser do tipo TIP
			if($etip == true)
			{
				$temp = array_combine($itens,$itensdesc);
				$templ = array_combine($itens,$lks);
				$tempimg = array_combine($itens,$itemimg);
				$temploc = array_combine($itens,$locimg);
				$itensdesc = array();
				$itens = array();
				$lks = array();
				$itemimg = array();
				$locimg = array();
				$tips = explode(",",$tips);
				foreach($tips as $t)
				{
					$itens[] = $t;
					if($temp[$t] != ""){$itensdesc[] = $temp[$t];}else{$itensdesc[] = $t;}
					if($templ[$t] != ""){$lks[] = $templ[$t];}else{$lks[] = "";}
					if($tempimg[$t] != ""){$itemimg[] = $tempimg[$t];}else{$itemimg[] = "";}
					if($temploc[$t] != ""){$locimg[] = $temploc[$t];}else{$locimg[] = "";}
				}
			}
			$res_count = $layer->getNumresults();
			$sopen = $layer->open();
			if($sopen == MS_FAILURE){return "erro";}
			for ($i = 0; $i < $res_count; ++$i)
			{
				$valori = array();
				$result = $layer->getResult($i);
				$shp_index  = $result->shapeindex;
				$shape = $layer->getfeature($shp_index,-1);
				$conta = 0;
				foreach ($itens as $it)
				{
					$val = $shape->values[$it];
					$link = $lks[$conta];
					foreach($itens as $t)
					{
						$valtemp = $shape->values[$t];
						$busca = '['.$t.']';
						$link = str_replace($busca,$valtemp,$link);
					}
					$img = "";
					if($locimg[$conta] != "" && $itemimg[$conta] != "")
					{$img = "<img src='".$locimg[$conta]."//".$shape->values[$itemimg[$conta]]."' //>";}
					else
					if($itemimg[$conta] != "")
					{$img = "<img src='".$shape->values[$itemimg[$conta]]."' //>";}
					
					$arraytemp = array(
						"alias"=>$this->converte($itensdesc[$conta]),
						"valor"=>$this->converte($val),
						"link"=>$link,
						"img"=>$img
					);
					if($etip==false)
					{$valori[] = $arraytemp;}
					else
					{$valori[$it] = $arraytemp;}
					$conta = $conta + 1;
				}
				$resultado[] = $valori;
			}
			$layer->close();
		}
		else
		{$resultado[] = " ";}
		return $resultado;
	}
	function converte($texto)
	{
		if (function_exists("mb_convert_encoding"))
		{
			if (!mb_detect_encoding($texto,"UTF-8",true))
			{$texto = mb_convert_encoding($texto,"UTF-8","ISO-8859-1");}
		}
		return $texto;
	}
}
?>